API Reference
=============

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: locust_telemetry.entrypoint
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.logger
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.metadata
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.common.helpers
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.core.cli
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.coordinator
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.events
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.exceptions
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.handlers
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.manager
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.plugin
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.core.recorder
   :members:
   :undoc-members:

.. automodule:: locust_telemetry.recorders.json.handlers
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.json.plugin
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.json.recorder
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.otel.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.otel.handlers
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.otel.otel
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.otel.plugin
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: locust_telemetry.recorders.otel.recorder
   :members:
   :undoc-members:
   :show-inheritance:
